call_interface!() { /* proc-macro */ }Expand description
Call a function in a crate interface.
It is not necessary to call it in the same crate as the implementation, but it is required that these crates are linked together.
See the crate-level documentation for more details.